from rply import LexerGenerator


generator = LexerGenerator()

generator.ignore(r"\s+")  # ignore all whitespace
generator.ignore(r"rooWhisper.*")  # Ignore single line comment

generator.add("STRING", r'''("[^"\\]*(\\.[^"\\]*)*"|'[^'\\]*(\\.[^'\\]*)*')''')

generator.add("rooPog", "rooPog")



import roolang

def main(thing: str):
    roolang.parser.build().parse(roolang.generator.build().lex('1 + 1')).eval()

if __name__ == '__main__':
    while True:
        try:
            i = input("rooPog: ")
            main(i)
        except KeyboardInterrupt:
            exit()



from setuptools import setup, find_packages

with open('README.md', encoding='utf-8') as f:
    readme = f.read()


setup(
    name='roolang',
    author="Cryptex",
    url='https://github.com/rooLang/rooLang',
    project_urls={
        "Issue tracker": "https://github.com/rooLang/rooLang/issues",
        "Discord": "https://discord.gg/n625ahZAtZ",
    },
    version="0.0.2a",
    packages=find_packages(),
    license="AGPLv3",
    description='A language for roo',
    long_description=readme,
    long_description_content_type="text/markdown",
    include_package_data=True,
    classifiers=[
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 3 :: Only",

    ],
)



from roolexer import generator

from typing import List
from rply import ParserGenerator, Token


parser = ParserGenerator([l.name for l in generator.rules])


class rooBulli(SyntaxError):
    pass

@parser.production("main : expr")
def main(p: List[str]) -> str:
    return p[0]

@parser.production('string : STRING')
def string(p: List[str]) -> str:
    return p[0].getstr().strip("'").strip('"')

@parser.production("expr : rooPog string")
def rooPog(p: List[str]) -> None:
    ...
    

@parser.error
def rooBulli_error_handler(token):
    raise rooBulli(f"rooBulli: Unexpected {token.gettokentype()} in {token.getsourcepos()}\nvalue : '{token.getstr()}'")
